pub async fn sniff<'de, const N: usize, T>(chart: Chart<N, T>)where
    T: 'static + Debug + Clone + Serialize + DeserializeOwned + Sync + Send,
This listens only, mapping the cluster without announcing itself. Usefull for clients on the same subnet trying to find nodes to contact. You can drop the future but then the chart will no longer be updated.

Note

Take care not to call maintain anywhere