Function instance_chart::discovery::found_majority
source · [−]pub async fn found_majority<const N: usize, T>(
chart: &Chart<N, T>,
full_size: u16
) where
T: 'static + Debug + Clone + Serialize + DeserializeOwned, Expand description
Block until a majority of nodes have been found. Usefull when implementing vote based consensus such as Raft.